# Van't Hoff Analysis

This repo contains code that perform van't Hoff analysis on PCT curves for the hydogenation process of metal hydrides.

## Installation

This package is not published to PyPi, so it is best installed using pip's git remote support:

```
pip install git+https://github.nrel.gov/EMN/vant-hoff-analysis.git
```